<?php

declare(strict_types=1);

/**
 * This file is part of the Carbon package.
 *
 * (c) Brian Nesbitt <brian@nesbot.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */

namespace Tests\CarbonInterval\Fixtures;

trait MixinTrait
{
    public function andAgain()
    {
        return $this->times(2);
    }

    public function copyAndAgain()
    {
        return $this->copy()->andAgain();
    }
}
